/*
 *************
 * Copyright *
 *************
 *
 * Copyright (C) 2010 Christoph Zauner
 */

/*
 ***********
 * License *
 ***********
 *
 * This file is part of Rihamark.
 * 
 * Rihamark is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Rihamark is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Rihamark.  If not, see <http://www.gnu.org/licenses/>.
 */

package rmk.SPInterfaces;

import rmk.core.Debug;
import java.io.File;
import java.util.ArrayList;
import org.simpleframework.xml.*;
import rmk.SPArguments.SPArgument;
import rmk.SPArguments.TestItem;
import rmk.core.Hash;

/**
 * Service provider interface (SPI) for algorithm plugins.
 *
 * @author Christoph Zauner
 */
public abstract class Algorithm extends TestItem {

	@Attribute private String name;
	private String bundleName;
	private String description;
	private boolean accessToHashValues;

	public Algorithm
	(
		String name,
		String bundleName,
		String description,
		boolean accessToHashValues
	)
	{
	    this.name = name;
		this.bundleName = bundleName;
		this.description = description;

		this.accessToHashValues = accessToHashValues;

		Debug.debugPrint("Constructor Algortihm");
	}

	public abstract double cmpImages(File fileA, File fileB);

	public abstract Hash getHash(File file);

	public abstract double cmpHashes(Hash hashA, Hash hashB);

	@Override
	public String toString() {
		return getName();
	}


	/*****************************/
	/* getter and setter methods */
	/*****************************/


	/**
	 * @return the name of the algorithm
	 */
	public String getName() {
		return name;
	}

	/**
	 * @return the accessToHashValues
	 */
	public boolean isAccessToHashValues() {
		return accessToHashValues;
	}

	/**
	 * @return the bundleName
	 */
	public String getBundleName() {
		return bundleName;
	}

	/**
	 * @return the description
	 */
	public String getDescription() {
		return description;
	}

} // end of class
