/*
 *************
 * Copyright *
 *************
 *
 * Copyright (C) 2010 Christoph Zauner
 */

/*
 ***********
 * License *
 ***********
 *
 * This file is part of Rihamark.
 * 
 * Rihamark is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Rihamark is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Rihamark.  If not, see <http://www.gnu.org/licenses/>.
 */

package rmk.core;

import java.util.ArrayList;
import java.util.logging.Level;
import java.util.logging.Logger;
import java.util.ServiceLoader;
import rmk.SPInterfaces.Analyzer;

public class AnalyzerService {

    private static AnalyzerService service;
    private ServiceLoader<Analyzer> loader;
	private ArrayList<Analyzer> analyzers = new ArrayList<Analyzer>();

    /**
     * Creates a new instance of this service.
     */
    private AnalyzerService() {
        loader = ServiceLoader.load(Analyzer.class);

		for(Analyzer analyzer: loader) {
			analyzers.add(analyzer);
		}

		Debug.debugPrint(Debug.LogLevel.DEBUG1, "Initial loading of the following analyzer service providers: " + analyzers);
    }

    /**
     * Retrieve the singleton static instance of DictionaryService.
     */
    public static synchronized AnalyzerService getInstance() {
        if (service == null) {
            service = new AnalyzerService();
        }
        return service;
    }

	/**
	 *
	 * @return ArrayList<String> containing the names of all found
	 * Analyzer Service Providers.
	 */
    public ArrayList<String> getSrvProvNames() {
        ArrayList<String> serviceProviderNames = new ArrayList<String>();

		for(Analyzer analyzer: analyzers) {
			serviceProviderNames.add(analyzer.getName());
		}

        return serviceProviderNames;
    }

	/**
	 *
	 * @return
	 */
    public Analyzer getSrvProv(int idxOfSrvProv) {
		return analyzers.get(idxOfSrvProv);
    }

//	public Analyzer getSrvProvInstance(int idxOfSrvProv) {
//		Analyzer newAnalyzer = null;
//
//		try {
//			newAnalyzer = analyzers.get(idxOfSrvProv).getClass().newInstance();
//		} catch (InstantiationException ex) {
//			Logger.getLogger(AnalyzerService.class.getName()).log(Level.SEVERE, null, ex);
//		} catch (IllegalAccessException ex) {
//			Logger.getLogger(AnalyzerService.class.getName()).log(Level.SEVERE, null, ex);
//		}
//
//		return newAnalyzer;
//	}

} // end of class
