/*
 *************
 * Copyright *
 *************
 *
 * Copyright (C) 2010 Christoph Zauner
 */

/*
 ***********
 * License *
 ***********
 *
 * This file is part of Rihamark.
 * 
 * Rihamark is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Rihamark is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Rihamark.  If not, see <http://www.gnu.org/licenses/>.
 */

package rmk.core;

import java.util.ArrayList;
import java.util.logging.Level;
import java.util.logging.Logger;
import rmk.SPInterfaces.Attack;
import java.util.ServiceLoader;

public class AttackService {

    private static AttackService service;
    private ServiceLoader<Attack> loader;
	private ArrayList<Attack> attacks = new ArrayList<Attack>();

    /**
     * Creates a new instance of this service.
     */
    private AttackService() {
        loader = ServiceLoader.load(Attack.class);

		for(Attack attack: loader) {
			attacks.add(attack);
		}

		Debug.debugPrint(Debug.LogLevel.DEBUG1, "Initial loading of the following attack service providers: " + attacks);
    }

    /**
     * Retrieve the singleton static instance of DictionaryService.
     */
    public static synchronized AttackService getInstance() {
        if (service == null) {
            service = new AttackService();
        }
        return service;
    }

	/**
	 *
	 * @return ArrayList<String> containing the names of all found
	 * Attack Service Providers.
	 */
    public ArrayList<String> getSrvProvNames() {
        ArrayList<String> serviceProviderNames = new ArrayList<String>();

		for(Attack attack: attacks) {
			serviceProviderNames.add(attack.getName());
		}

        return serviceProviderNames;
    }

	/**
	 *
	 * @return
	 */
    public Attack getSrvProv(int idxOfSrvProv) {
		return attacks.get(idxOfSrvProv);
    }

	public Attack getSrvProvInstance(int idxOfSrvProv) {
		Attack newAttack = null;
		
		try {
			newAttack = attacks.get(idxOfSrvProv).getClass().newInstance();
		} catch (InstantiationException ex) {
			Logger.getLogger(AttackService.class.getName()).log(Level.SEVERE, null, ex);
		} catch (IllegalAccessException ex) {
			Logger.getLogger(AttackService.class.getName()).log(Level.SEVERE, null, ex);
		}

		return newAttack;
	}

} // end of class
