/*
 *************
 * Copyright *
 *************
 *
 * Copyright (C) 2010 Christoph Zauner
 */

/*
 ***********
 * License *
 ***********
 *
 * This file is part of Rihamark.
 * 
 * Rihamark is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Rihamark is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Rihamark.  If not, see <http://www.gnu.org/licenses/>.
 */

package rmk.core;

import java.util.LinkedList;
import rmk.SPInterfaces.Algorithm;

/**
 * A run saves the outcome of a benchmarking run collected when applying
 * an algorithms to a specific modifictation/manipulation
 * (e.g. scaling + jpeg compression).
 *
 * @author christoph
 */
public class Run {

	private Algorithm algorithm;  // TODO not used
	private Test test;
	private LinkedList<Result> results = new LinkedList<Result>();
	private long elapsedTime = 0;

	public Run(Test test, Algorithm algorithm) {
		this.test = test;
		this.algorithm = algorithm;
	}

	@Override
	public String toString() {
		return "Run with algorithm: " + getAlgorithm();
	}

	/**
	 * @return the elapsedTime in Seconds
	 */
	public long getElapsedTimeSec() {
		return elapsedTime / 1000;
	}

	public double getMeanDistance() {
		double sumDistance = 0;

		for(Result result: results) {
			sumDistance += result.distance;
		}

		return sumDistance / results.size();
	}

	
	/*****************************/
	/* getter and setter methods */
	/*****************************/


	/**
	 * @return the test
	 */
	public Test getTest() {
		return test;
	}

	/**
	 * @param test the test to set
	 */
	public void setTest(Test test) {
		this.test = test;
	}

	/**
	 * @return the algorithm
	 */
	public Algorithm getAlgorithm() {
		return algorithm;
	}

	/**
	 * @param algorithm the algorithm to set
	 */
	public void setAlgorithm(Algorithm algorithm) {
		this.algorithm = algorithm;
	}

	/**
	 * @return the results
	 */
	public LinkedList<Result> getResults() {
		return results;
	}

	/**
	 * @param results the results to set
	 */
	public void setResults(LinkedList<Result> results) {
		this.results = results;
	}

	/**
	 * @return the elapsedTime
	 */
	public long getElapsedTime() {
		return elapsedTime;
	}

	/**
	 * @param elapsedTime the elapsedTime to set
	 */
	public void setElapsedTime(long elapsedTime) {
		this.elapsedTime = elapsedTime;
	}

}
