/*
 *************
 * Copyright *
 *************
 *
 * Copyright (C) 2010 Christoph Zauner
 */

/*
 ***********
 * License *
 ***********
 *
 * This file is part of Rihamark.
 * 
 * Rihamark is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Rihamark is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Rihamark.  If not, see <http://www.gnu.org/licenses/>.
 */

package rmk.plugins.algorithms.pHash;

import org.simpleframework.xml.*;

import rmk.core.Debug;
import java.io.File;
import org.pHash.pHash;
import org.pHash.MHImageHash;
import rmk.SPArguments.*;
import rmk.SPInterfaces.Algorithm;
import rmk.core.Hash;
import rmk.core.MHHash;

/**
 *
 * @author christoph
 */
public class MH extends Algorithm {


	private static String name = "Marr/Hildreth Operator Based Image Hash";
	private static String bundleName = "pHash";
	private static String description =
			"Fast inter testing: Supported";

	/* start: service provider options */
	@Element private SpinnerDbl alpha;
	@Element private SpinnerDbl level;
	/* end: service provider options */

	public MH() {
		super(name, bundleName, description, true);
		Debug.debugPrint(Debug.LogLevel.DEBUG2,"Constructor in " + this.getClass().getCanonicalName());

		if(!deserialization) {
			// argument
			alpha = new SpinnerDbl(2.0, "Wavelet scale factor", 0.0, 100.0, 0.1);
			addSPArgument(alpha);

			// argument
			level = new SpinnerDbl(1.0, "Scale factor level", 0.0, 100.0, 0.1);
			addSPArgument(level);
		}
	}

	@Override
	public Hash getHash(File file) {

		pHash.setMHImageHashArgs((float)alpha.getValue(), (float)level.getValue());
		byte[] hashValue = pHash.getMHImageHash(file).getHash();
		MHHash hash = new MHHash(hashValue);

		return hash;
	}

	@Override
	public double cmpHashes(Hash hashA, Hash hashB) {
		MHImageHash phHashA = new MHImageHash();
		MHImageHash phHashB = new MHImageHash();

		phHashA.setHash(((MHHash)hashA).getHashValue());
		phHashB.setHash(((MHHash)hashB).getHashValue());
		
		return pHash.getMHImageHashDistance(phHashA, phHashB);
	}

	@Override
	public double cmpImages(File fileA, File fileB) {
		pHash.setMHImageHashArgs((float)alpha.getValue(), (float)level.getValue());
		return pHash.getMHImageHashDistance(fileA.toString(), fileB.toString());
	}

} // end of class
