/*
 *************
 * Copyright *
 *************
 *
 * Copyright (C) 2010 Christoph Zauner
 */

/*
 ***********
 * License *
 ***********
 *
 * This file is part of Rihamark.
 * 
 * Rihamark is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Rihamark is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Rihamark.  If not, see <http://www.gnu.org/licenses/>.
 */

package rmk.plugins.attacks.imageJ;

import java.io.File;
import rmk.core.Debug;
import rmk.SPArguments.CheckBox;
import rmk.SPArguments.ComboBox;
import rmk.SPArguments.SpinnerInt;
import rmk.SPInterfaces.Attack;
import rmk.core.Debug.LogLevel;

import org.simpleframework.xml.*;
import rmk.SPArguments.SpinnerDbl;

public class GaussianBlur extends Attack {

	/* start: mandatory service provider variables */
	private static String name = "Gaussian Blur";
	private static String bundleName = "Rihamark Default Attack Plugins (using ImageJ)";
	private static String description = "Self explanatory.";
	/* end: mandatory service provider variables */

	/* start: service provider options */
	@Element private SpinnerDbl sigma;
	/* end: service provider options */

	private ImageJ attack;

	public GaussianBlur() {
		super(name, bundleName, description);
		Debug.debugPrint(LogLevel.DEBUG2, "Constructor in " + this.getClass().getCanonicalName());

		if(!deserialization) {
			// argument
			sigma = new SpinnerDbl(2.0, "Sigma", 1.0, 100.0, 0.1);
			addSPArgument(sigma);
		}
	}

	public void runAttack(String file){
	    Debug.debugPrint(LogLevel.DEBUG1,"Running attack: " + getName());

		String args = "sigma=" + sigma.getValue();

		attack = new ImageJ(new File(file), "Gaussian Blur...", args);
		attack.run();
	}


	/*****************************/
	/* getter and setter methods */
	/*****************************/


} // end of class
