/*
 *************
 * Copyright *
 *************
 *
 * Copyright (C) 2010 Christoph Zauner
 */

/*
 ***********
 * License *
 ***********
 *
 * This file is part of Rihamark.
 * 
 * Rihamark is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Rihamark is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Rihamark.  If not, see <http://www.gnu.org/licenses/>.
 */

package rmk.plugins.attacks.imageJ;

import java.io.File;
import rmk.core.Debug;
import rmk.SPArguments.CheckBox;
import rmk.SPArguments.ComboBox;
import rmk.SPArguments.SpinnerInt;
import rmk.SPInterfaces.Attack;
import rmk.core.Debug.LogLevel;

import org.simpleframework.xml.*;

public class Rotation extends Attack {

	/* start: mandatory service provider variables */
	private static String name = "Rotation";
	private static String bundleName = "Rihamark Default Attack Plugins (using ImageJ)";
	private static String description = "Self explanatory.";
	/* end: mandatory service provider variables */

	/* start: service provider options */
	@Element private SpinnerInt angle;
	@Element private ComboBox interpolation;
	@Element private CheckBox enlarge;
	/* end: service provider options */

	private ImageJ attack;

	public Rotation() {
		super(name, bundleName, description);
		Debug.debugPrint(LogLevel.DEBUG2, "Constructor in " + this.getClass().getCanonicalName());

		if(!deserialization) {
			// argument
			angle = new SpinnerInt(45, "Degrees", 0, 360, 1);
			addSPArgument(angle);

			// argument
			interpolation = new ComboBox("None", "Interpolation", new String[] {"None", "Bilinear", "Bicubic"});
			addSPArgument(interpolation);

			// argument
			enlarge = new CheckBox(true, "Enlarge Image to Fit Result");
			addSPArgument(enlarge);
		}

	}

	public void runAttack(String file){
	    Debug.debugPrint(LogLevel.DEBUG1,"Running attack: " + getName());

	    String argEnlarge = "";
	    if (enlarge.getValue()) {
			argEnlarge = "enlarge";
	    }

		String args = String.format(
			"angle=%d interpolation=%s %s",
			angle.getValue(),
			interpolation.getValue(),
			argEnlarge
		);

		attack = new ImageJ(new File(file), "Rotate... ", args);
		attack.run();
	}


	/*****************************/
	/* getter and setter methods */
	/*****************************/

	// TODO remove these superfluous methods.

	/**
	 * @return the angle
	 */
	public SpinnerInt getAngle() {
		return angle;
	}

	/**
	 * @param angle the angle to set
	 */
	public void setAngle(SpinnerInt angle) {
		this.angle = angle;
	}

	/**
	 * @return the interpolation
	 */
	public ComboBox getInterpolation() {
		return interpolation;
	}

	/**
	 * @param interpolation the interpolation to set
	 */
	public void setInterpolation(ComboBox interpolation) {
		this.interpolation = interpolation;
	}

	/**
	 * @return the enlarge
	 */
	public CheckBox getEnlarge() {
		return enlarge;
	}

	/**
	 * @param enlarge the enlarge to set
	 */
	public void setEnlarge(CheckBox enlarge) {
		this.enlarge = enlarge;
	}

} // end of class
