/*
 *************
 * Copyright *
 *************
 *
 * Copyright (C) 2010 Christoph Zauner
 */

/*
 ***********
 * License *
 ***********
 *
 * This file is part of Rihamark.
 * 
 * Rihamark is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Rihamark is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Rihamark.  If not, see <http://www.gnu.org/licenses/>.
 */

package rmk.plugins.attacks.imageJ;

import ij.IJ;
import ij.ImagePlus;
import java.io.File;
import rmk.core.Debug;
import org.simpleframework.xml.*;
import rmk.SPArguments.ComboBox;
import rmk.SPArguments.SpinnerDbl;
import rmk.SPInterfaces.Attack;
import rmk.core.Debug.LogLevel;

/**
 * ImageJ implements the scaling logic in the GUI.
 * Therefore we have to reimplement it. The actual ImageJ
 * command that is executed is "Size..."
 *
 * ImageJ uses the floor function when calculating the new
 * size of an image (if one dimension is adjusted
 * proportionally). Gimp uses the round function.
 */
public class Scale extends Attack {

	/* start: mandatory service provider variables */
	private static String name = "Scale";
	private static String bundleName = "Rihamark Default Attack Plugins (using ImageJ)";
	private static String description = "Self explanatory.";
	/* end: mandatory service provider variables */

	/* start: service provider options */
	@Element private SpinnerDbl xScale;
	@Element private SpinnerDbl yScale;
	@Element private ComboBox interpolation;
	/* end: service provider options */

	private ImageJ attack;

	public Scale() {
		super(name, bundleName, description);
		Debug.debugPrint(Debug.LogLevel.DEBUG2,"Constructor in " + this.getClass().getCanonicalName());

		if(!deserialization) {
			// argument
			xScale = new SpinnerDbl(0.5, "X Scale", 0, 100, 0.1);
			addSPArgument(xScale);

			// argument
			yScale = new SpinnerDbl(0.5, "Y Scale", 0, 100, 0.1);
			addSPArgument(yScale);

			// argument
			interpolation = new ComboBox("None", "Interpolation", new String[] {"None", "Bilinear", "Bicubic"});
			addSPArgument(interpolation);
		}
	}

    public void runAttack(String file){
	    Debug.debugPrint(Debug.LogLevel.DEBUG1, "Running attack: " + getName());

		ImagePlus imagePlus = IJ.openImage(file);
		int argWidth = (int) (imagePlus.getWidth() * xScale.getValue());
		int argHeight = (int) (imagePlus.getHeight() * yScale.getValue());

	    String args = String.format(
			"width=%d height=%d interpolation=%s",
		    argWidth,
			argHeight,
		    interpolation.getValue()
		);

		attack = new ImageJ(new File(file), "Size...", args);
		attack.run();
	}


	/*****************************/
	/* getter and setter methods */
	/*****************************/


} // end of class
